import argparse
import os
import sys

from zett.commands import commit
from zett.commands import generate
from zett.commands import list as _list
from zett.commands import search


def _get_version() -> str:
    """Prints version information of rasa tooling and python."""
    if sys.version_info >= (3, 8):  # pragma: >=3.8 cover
        import importlib.metadata as importlib_metadata
    else:  # pragma: <3.8 cover
        import importlib_metadata

    return importlib_metadata.version("zett")


def create_argument_parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(
        prog="zett",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        description="",
    )

    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version=f"%(prog)s {_get_version()}",
        help="Current program version",
    )
    parser.add_argument(
        "-d",
        "--directory",
        default=os.getcwd(),
        help="Directory containing your zettels",
    )

    parents = [argparse.ArgumentParser(add_help=False)]
    subparsers = parser.add_subparsers(help="Zett commands")

    commands = [generate, _list, search, commit]
    [command.add_subparser(subparsers, parents) for command in commands]

    return parser
