from __future__ import annotations

import argparse
import os

from rich.console import Console
from rich.table import Table

console = Console()
table = Table(title="Zettel information")


def add_subparser(
    subparsers: argparse._SubParsersAction,  # type: ignore
    parents: list[argparse.ArgumentParser],
) -> None:
    parser = subparsers.add_parser(
        "list",
        parents=parents,
        help="List all the zettels",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )

    parser.set_defaults(func=run)


def run(args: argparse.Namespace) -> int:
    zettel_files = os.listdir(args.directory)
    content_groups = []
    for zettel in zettel_files:
        zettel_file = os.path.join(args.directory, zettel)
        zettel_contents = []
        with open(zettel_file, encoding="utf-8") as fd:
            zettel_contents = fd.readlines()[2:][:3]

        splitted = [
            content.strip().split(": ")[1] for content in zettel_contents
        ]
        splitted.insert(0, zettel)
        content_groups.append(splitted)

    table.add_column("Filename")
    table.add_column("Title")
    table.add_column("Date")
    table.add_column("Tags")

    for content in content_groups:
        filename = content[0]
        title = content[1].replace('"', "")
        date = content[2]
        tags = content[3].replace("[", "").replace("]", "")

        table.add_row(filename, title, date, tags)

    console.print(table)
    return 0
