from __future__ import annotations

import argparse
import os
from typing import Any

from rich.console import Console
from rich.table import Table

console = Console()
table = Table(title="Zettel search")


def add_subparser(
    subparsers: argparse._SubParsersAction,  # type: ignore
    parents: list[argparse.ArgumentParser],
) -> None:
    parser = subparsers.add_parser(
        "search",
        parents=parents,
        help="Search for a specific zettel",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    parser.add_argument("term", help="The search term to be used")

    parser.set_defaults(func=run)


def run(args: argparse.Namespace) -> int:
    zettel_files = os.listdir(args.directory)
    files_with_terms: dict[str, Any] = {}
    for zettel in zettel_files:
        zettel_file = os.path.join(args.directory, zettel)
        zettel_contents = []
        with open(zettel_file, encoding="utf-8") as fd:
            zettel_contents = [line.strip() for line in fd.readlines()]

        for content in zettel_contents:
            if args.term in content:
                if zettel not in files_with_terms:
                    files_with_terms[zettel] = {"lines": []}

                files_with_terms[zettel]["lines"].append(content)

    table.add_column("Filename")
    table.add_column("Matched Line")

    for filename, contents in files_with_terms.items():
        parsed_contents = ""
        for content in contents["lines"]:
            content = (
                content.strip()
                .replace("[", "")
                .replace("]", "")
                .replace('"', "")
            )
            parsed_contents += f"- {content.strip()}\n"

        table.add_row(filename, parsed_contents)

    console.print(table)
    return 0
